package com.example.wholeestate.controller;


import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.model.SysUser;
import com.example.wholeestate.service.ICustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <p>
 *  用户
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@RestController
@RequestMapping("/")
@Api(value = "用户 API", description = "用户 API")
public class CustomerController extends BaseController {

    @Autowired
    private ICustomerService iCustomerService;

    /**
     * 自定义方法绑定请求参数的Date类型
     *
     * @param request
     * @param binder
     * @throws Exception
     */
    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @ApiOperation(value = "会员列表", notes = "会员列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body",dataType = "String",name = "parameter",value = "pageNum:分页第几页,pageSize:每页长度,phone:手机号，name：姓名，beginDate:开始时间，endDate:结束时间")
    })
    @RequestMapping(value = "/customerList", method = RequestMethod.POST)
    public ResponseBean buildingList(@RequestBody String parameter, HttpSession session){
        ResponseBean  responseBean = iCustomerService.customerList(parameter);
        return responseBean;
    }

    @RequestMapping(value = "/customerSelectId/{id}", method = RequestMethod.GET)
    @ApiOperation(value = "会员详情", notes = "会员详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass=Integer.class, name = "id", value = "会员id"),
    })
    public ResponseBean customerSelectId(@PathVariable(value = "id") Integer id, HttpSession session){
        ResponseBean  responseBean = iCustomerService.customerSelectId(id);
        return responseBean;
    }

}
